@@ -102,8 +102,8 @@ class VCSFileInitHook(hook.Hook):
                                        bridge.VCSStorage())
         cacheroot = repo_cache_dir(self.repo.config)
         if not os.access(cacheroot, os.W_OK):
-            raise ValueError('directory %r is not writable (check  option)'
-                             % (cacheroot, CACHEROOT))
+            raise ValueError('directory %r is not writable (check "local-repo-'
+                             'cache-root" option)' % cacheroot)
 
 
 
@@ -119,7 +119,7 @@ class VCSFileStartHook(hook.Hook):
             try:
                 reposrset = session.execute(
                     'Any R, RT, RE, RLC, RSU, RP, RIRC WHERE R is Repository, '
-                    'R type "mercurial", NOT (R local_cache NULL AND R path NULL),'
+                    'NOT (R local_cache NULL AND R path NULL),'
                     'R type RT, R encoding RE, R local_cache RLC, R source_url RSU, R path RP,'
                     'R import_revision_content RIRC, R cw_source S, S name "system"')
                 for vcsrepo in reposrset.entities():
@@ -129,7 +129,7 @@ class VCSFileStartHook(hook.Hook):
                         repo.error(str(ex))
                         continue
                     except Exception:
-                        repo.exception('error while retreiving handler for %s',
+                        repo.exception('error while retrieving handler for %s',
                                        vcsrepo.eid)
                         continue
                     if (repo.config['repository-import'] or vcsrepo.import_revision_content) \
