@@ -207,7 +207,7 @@ class HGRepository(repo.VCSRepository):
             else:
                 self.error('detected copy or rename of %s@%s but unable'
                            ' to find associated version content',
-                           oldfile, rset.args['cs'])
+                           oldfile, pvc.args['cs'])
         return bridge.import_version_content(session, self.eid, reveid, upath,
                                              date, **vcdata)
 
