@@ -126,14 +126,16 @@ class RepositoryCheckOutInstructionsView(EntityView):
     def entity_call(self, entity):
         w = self.w
         _ = self._cw._
-        w(u'<h3>%s</h3>' % _('Browse source'))
-        w(u'<p>%s</p>' % _('You can browse the source code by following <a href="%s">this link</a>.')
-          % xml_escape(entity.source_url))
+        url_scheme = entity.source_url.split(':')[0]
+        if url_scheme.startswith('http'):
+            w(u'<h3>%s</h3>' % _('Browse source'))
+            w(u'<p>%s</p>' % _('You can browse the source code by following <a href="%s">this link</a>.')
+              % xml_escape(entity.source_url))
         w(u'<h3>%s</h3>' % _('Command-Line Access'))
         if entity.has_anonymous_access:
-            msg = _('Non-members may check out a read-only working copy anonymously over HTTP.')
+            msg = _('Non-members may check out a read-only working copy anonymously over %s.') % xml_escape(url_scheme.upper())
         else:
-            msg = _('Members only may check out working copy over HTTP.')
+            msg = _('Members only may check out working copy over %s.') % xml_escape(url_scheme.upper())
         w(u'<p>%s</p>' % msg)
         w(u'<p>%s</p>' % _('Use this command to check out the latest project source code:'))
         w(u'<pre>')
